@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
 
 from django.db import models, migrations
 
@@ -14,13 +13,13 @@ class Migration(migrations.Migration):
         migrations.AlterField(
             model_name='record',
             name='report',
-            field=models.ForeignKey(related_name='records', to='dmarc.Report'),
+            field=models.ForeignKey(related_name='records', to='dmarc.Report', on_delete=models.CASCADE),
             preserve_default=True,
         ),
         migrations.AlterField(
             model_name='result',
             name='record',
-            field=models.ForeignKey(related_name='results', to='dmarc.Record'),
+            field=models.ForeignKey(related_name='results', to='dmarc.Record', on_delete=models.CASCADE),
             preserve_default=True,
         ),
     ]
